import unittest

import os, sys
test_root = os.path.dirname(os.path.abspath(__file__))
os.chdir(test_root)
sys.path.insert(0, os.path.dirname(test_root))
sys.path.insert(0, test_root)

from bottle.ext.pystache import Template, template, view

class TestPystacheTemplate(unittest.TestCase):
    def test_interface(self):
        from bottle.ext.pystache import Template, template, view
        from bottle.ext.pystache import PystacheTemplate, pystache_template, pystache_view

    def test_string(self):
        """ Pystache string"""
        t = Template('start {{var}} end').render(var='var')
        self.assertEqual('start var end', t)

    def test_file(self):
        """ Pystache file"""
        t = Template(name='./views/simple.tpl').render(var='var')
        self.assertEqual('start var end\n', t)

    def test_name(self):
        """ Pystache lookup by name """
        t = Template(name='simple', lookup=['./views/']).render(var='var')
        self.assertEqual('start var mustache end\n', t)

    def test_notfound(self):
        """ Unavailable templates"""
        self.assertRaises(Exception, Template, name="abcdef")

    def test_error(self):
        """ Exceptions"""
        template = Template('{{#block_not_closed}}')
        self.assertRaises(Exception, template.render)

    def test_partials(self):
        """ Pystache lookup and partials """
        t = Template(name='base', lookup=['./views/']).render(var='v')
        self.assertEqual('o\ncvc\no\n', t)
        t = Template('o{{> partial}}o\n', lookup=['./views/']).render(var='v')
        self.assertEqual('o\ncvc\no\n', t)

    def test_template_shortcut(self):
        result = template('start {{var}} end', var='middle')
        self.assertEqual(u'start middle end', result)

    def test_view_decorator(self):
        @view('start {{var}} end')
        def test():
            return dict(var='middle')
        self.assertEqual(u'start middle end', test())


try:
  import pystache
except ImportError:
  print "WARNING: No Pystache template support. Skipping tests."
  del TestPystacheTemplate

if __name__ == '__main__': #pragma: no cover
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
from distutils.core import setup

if sys.version_info < (2,5):
    raise NotImplementedError("Sorry, you need at least Python 2.5 or Python 3.x to use bottle.")

try:
    from distutils.command.build_py import build_py_2to3 as build_py
except ImportError:
    from distutils.command.build_py import build_py

setup(name='bottle-pystache',
      version='0.0.1',
      description='Bottle Pystache template wrappers',
      long_description='This project is an easy to use Bottle wrapper to Pystache.',
      author='AleiPhoenix',
      author_email='aleiphoenix@gmail.com',
      url='https://github.com/aleiphoenix/bottle-pystache',
      py_modules=['bottle_pystache'],
      scripts=['bottle_pystache.py'],
      license='MIT',
      platforms = 'any',
      cmdclass = {'build_py': build_py}
     )




import functools
import threading

import bottle

__all__ = ['PystacheTemplate', 'view']

class PystacheTemplate(bottle.BaseTemplate):
    ''' Pystache is a Python Mustache implementation.
        Set `View.template_extension` to be able to use partials,
        because partial calls are not handled by Bottle and Pystache works
        with only one extension, defined as `mustache` by default.
    '''

    try:
        extensions = bottle.BaseTemplate.extensions
    except AttributeError:
        # Bottle had a misspelling in BaseTemplate.
        # It is fixed in Bottle v0.10.
        extensions = bottle.BaseTemplate.extentions
    extensions.insert(0, 'mustache')

    def prepare(self, **options):
        from pystache import Renderer
        self.context = threading.local()
        self.context.vars = {}
        self.tpl = Renderer(search_dirs=self.lookup, **options)

    def render(self, *args, **kwargs):
        for dictarg in args:
            kwargs.update(dictarg)

        kwargs.update(self.defaults)
        out = self.tpl.render_path(self.filename, **kwargs)
        return out

view = functools.partial(bottle.view, template_adapter=PystacheTemplate)

